Learn R Programming

PesticideLoadIndicator (version 1.3.1)

check_substance_column_names: Check if column names of substances dataframe are valid

Description

checks for valid colum names and stops execution if problems are detected

Usage

check_substance_column_names(substances)

Value

No return value

Arguments

substances

Dataframe describing active ingredients of the applied pesticide products.