check_products_column_names: Check if column names of applied pesticide products dataframe are valid
Description
checks for valid colum names and stops execution if problems are detected
Usage
check_products_column_names(products)
Arguments
- products
Dataframe with raw pesticide application data.