check_substance_column_names: Check if column names of substances dataframe are valid
Description
checks for valid colum names and stops execution if problems are detected
Usage
check_substance_column_names(substances)
Arguments
- substances
Dataframe describing active ingredients of the applied pesticide products.